#
# spec file for package ineffassign
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           ineffassign
Version:        0.0.0+git20230610.0e73809
Release:        1.8
Summary:        Tool to detect ineffectual assignments in Go code
License:        MIT
URL:            https://github.com/gordonklaus/ineffassign
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source99:       %{name}-rpmlintrc
BuildRequires:  golang(API) >= 1.14

%description
This tool misses some cases because does not consider any type information in
its analysis. (For example, assignments to struct fields are never marked as
ineffectual.) It should, however, never give any false positives.

%prep
%setup -q
%setup -q -T -D -a 1

%build
go build \
   -buildmode=pie ;

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%defattr(-,root,root)
%doc README.md
%if 0%{?suse_version} < 1500
%doc LICENSE
%else
%license LICENSE
%endif
%{_bindir}/%{name}

%changelog
* Sat Aug 12 2023 jkowalczyk@suse.com
- Update to version 0.0.0+git20230610.0e73809:
  * A function is not deferred until after it and its args have been evaluated.
  * Update issue templates
  * Check length of builder.defers as maybePanic may be called outside of a function scope.
  * Do not mark named function results as used if an operation might panic but will not be recovered (i.e., when there is no defer statement).
  * Don't type-check the code being analyzed.
  * Missed a spot.
  * Don't treat nil initialization as assignment.
  * doc:  clarify meaning of ineffectual assignment
- Use _service mode manual as better alias name than disabled
* Tue Mar 16 2021 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to version 0.0.0+git20210225.2e10b26:
  * Don't disregard operations that occur prior to a variable escaping.
  * Move library code of the analyzer into pkg/ineffassign
  * Extra "is this file generated" logic into func
  * Ignore generated files.
  * Adjust testdata comments to match what analysistest expects.
  * Fix testdata compilation errors.
  * Re-add support for -n flag (and run go fmt)
  * Use analysis.Analyzer to implement ineffassign
  * Update "Usage" in README
  * Deprecate "-n" flag
  * Add support for ... syntax for recursive analysis
  * Ignore generated files
  * Add docs on tool install and usage
  * Terminate a block upon reaching a return statement.
  * avoid repeating type assertions by switching on `x := x.(type)`
  * Account for the pathological case where some clown redfined 'false'
  * Don't treat initialization to 'false' as assignment.
  * Packaging use go modules and vendor dependencies
  * Packaging add obs-service-go_modules disabled
  * Packaging drop BuildRequires: golang-packaging macros no longer used
  * Packaging add rpmlintrc
* Fri Jan  4 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Wed Jan  2 2019 ndas@suse.de
- enable tar_scm service
* Wed Jan  2 2019 opensuse-packaging@opensuse.org
- Update to version 0.0.0+git20180909.1003c8b:
  * Don't treat initialization to zero like `x := int64(0)` as assignment.
  * Guard against invalid code (break/continue outside of loop).
  * Definitely don't panic in maybePanic.
  * Mark named function results as used in operations that may panic.
  * Don't treat explicit initialization to zero as assignment; it is often used as shorthand for a bare declaration.
  * Support multiple path arguments on the command line.
  * Add a note to the README about limitations.
  * Slicing an array or taking the address of an array element causes the array to escape.
  * Use control flow analysis to find more useless assignments.
  * ignore vendor directories
* Tue Jul 10 2018 mrostecki@suse.com
- Initial release
